<?php

namespace App\Http\Controllers;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use App\Models\Admin;
use App\Models\Packeg;
use App\Models\User;
use App\Models\PromptsCategory;
use App\Models\Server;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Session;
use App\Models\Token;


class AdminController extends Controller
{
    public function dashboard()
    {
        Session::put('page', 'dashboard');

        // Counting total users
        $totalUser = User::count();
        $totalPlane = Packeg::count();
        $totalAdmins = Admin::count();
        $totalCountries = PromptsCategory::count();
        $totalServers = Server::count();
        // Counting premium users
        $premiumUser = User::where('login_mode', 'pro')->count();

        // Counting guest users
        $guestUser = User::where('login_mode', 'guest')->count();

        // Calculating token-related information
        $totalTokenCount = Token::sum('token_count');
        $totalTokenBuy = Token::sum('tokens_buy');
        $totalUseTokens = $totalTokenBuy - $totalTokenCount;

        // Calculating cradits-related information
        $totalCraditsCount = Token::sum('credits_count');
        $totalCraditsInit = Token::sum('init_credits');

        $totalUseCradits = $totalCraditsInit - $totalCraditsCount;


        return view('admin.admin_dashboard', compact(
            'totalUser',
            'premiumUser',
            'guestUser',
            'totalPlane',
            'totalAdmins',
            'totalCountries',
            'totalServers',
            'totalTokenCount',
            'totalTokenBuy',
            'totalUseTokens',
            'totalCraditsCount',
            'totalCraditsInit',
            'totalUseCradits'
        ));
    }

    public function login(Request $request)
    {
        $data = [
            'userName' => 'Mijanur',
            'email' => 'admin@admins',
            'full_name' => 'Mijan',
            'user_role' => 'super_admin',
            'password' => 'admin',
        ];

        $admin = Admin::all();

        // Sign in admin and go to dashboard after post
        if ($request->isMethod('post')) {
            $data = $request->all();

            // Validation for admin login
            $rules = [
                'email' => 'required|email|max:255',
                'password' => 'required',
            ];

            $messages = [
                'email.max' => 'Enter a valid email address.',
                'email.required' => 'Email is required.',
                'password.required' => 'Password is required.',
            ];

            $validator = Validator::make($request->all(), $rules, $messages);

            if ($validator->fails()) {
                return redirect()->back()
                    ->withErrors($validator)
                    ->withInput();
            }

            if (Auth::guard('admin')->attempt(['email' => $data['email'], 'password' => $data['password']])) {
                return redirect('admin/dashboard');
            } else {
                return redirect()->back()->with('error', 'Invalid Email or Password');
            }
        }

        return view('admin.admin_login');
    }

    public function logout()
    {
        Auth::guard('admin')->logout();
        return redirect('/admin');
    }




    ///Admin Section
    public function index()
    {
        session::put('page', 'administrator');
        $admins = Admin::latest()->paginate(3);
        // echo "<pre>"; print_r($admins);  die;
        return view('admin.Aindex', compact('admins'))->with('no', 1);
    }



    public function create()
    {

        return view('admin.Acreate');
    }

    //Submit function
    public function store(Request $request)
    {


        $admin = new Admin;
        $admin->userName = $request->input('userName');
        $admin->email = $request->input('email');
        $admin->password = $request->input('password');
        $admin->full_name = $request->input('full_name');
        // $admin->user_role = $request->input('user_role');
        $admin->user_role = 'super_admin';

        $admin->save();
        return redirect('admin/Aindex')->with('message', 'Admin added successfully!');
    }

    public function edit($id)
    {

        $admindata = Admin::find($id);

        return view('admin.Aedit', compact('admindata'));
    }

    public function update(Request $request, $id)
    {


        //check if new and confirm password is matching or not
        if ($request['password'] == $request['confirm_password']) {
            Admin::where('id', Auth::guard('admin')->user()->id)->update(['password' => bcrypt($request['password'])]);
            return redirect()->back()->with('message', 'Admin has been updated successfully!');
        } else {
            return redirect()->back()->with('error', 'new and confirm password not match!');
        }


        $admin->userName = $request->input('userName');
        $admin->email = $request->input('email');
        $admin->password = $request->input('password');
        $admin->full_name = $request->input('full_name');


        $admin->save();

        return redirect('admin/Aindex')->with('message', 'Admin updated successfully!');
    }

    public function destroy(Admin $admin, $id)
    {
        Admin::destroy(array('id', $id));
        return redirect()->back()->with('message', 'SubAdmin has been deleted.');
    }

    public function search()
    {
        $search_txt = $_GET['name'];

        $admins = Admin::where('userName', 'LIKE', '%' . $search_txt . '%')
            ->orWhere('full_name', 'LIKE', '%' . $search_txt . '%')

            ->paginate(1);


        return view('admin.Aindex', compact('admins'));
    }
}
