<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Server;
use App\Models\PromptsCategory;
use DB;
use Validator;

class AllserverController extends Controller
{
    public function index()
    {
        $allServers = DB::table('servers')
        ->join('prompts_categories', 'servers.country_id', '=', 'prompts_categories.id')
        ->select(
            'servers.id',
            'servers.server_name', 
            'prompts_categories.name as country_name', 
            'servers.vpn_username',
            'servers.vpn_password',
            'servers.provide_to',
        )
        ->get();

        return view("admin.servers.index", ['allServers' => $allServers])->with('no', 1);
    }

    public function getAllServers() {
        $servers = DB::table('servers')
        ->join('prompts_categories', 'servers.country_id', '=', 'prompts_categories.id')
        ->select(
            'servers.*',
            'servers.server_name', 
            'prompts_categories.name as country_name', 
            'prompts_categories.flag_name', 
        )
        ->get();

        return response()->json([
            'servers' => $servers,
        ], 200);
    }


public function create(Request $request)
{
    $categories = PromptsCategory::all();

    if ($request->ajax()) {
        $data = [
            'categories' => $categories,
        ];

        return response()->json($data);
    }

    return view('admin.servers.create', compact('categories'));
}



    public function store(Request $request)
    {
        $rules = [
            'country_id' => 'required',
            'country_vpn' => 'required',
            'server_name' => 'required',
            'vpn_username' => 'required',
            'vpn_password' => 'required',
            'udp' => $request->input('tcp') === null ? 'required' : 'nullable',
            'tcp' => $request->input('udp') === null ? 'required' : 'nullable',
            'provide_to' => 'required',
        ];

        $customMessage = [
            'country_id.required' => 'Please select a country.',
            'udp.required' => 'Either UDP or TCP should have a value.',
            'tcp.required' => 'Either TCP or UDP should have a value.',
        ];

        $validator = Validator::make($request->all(), $rules, $customMessage);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $server = new Server;
        $server->country_id = $request->country_id;
        $server->country_vpn = $request->country_vpn;
        $server->server_name = $request->server_name;
        $server->vpn_username = $request->vpn_username;
        $server->vpn_password = $request->vpn_password;
        $server->udp = $request->udp;
        $server->tcp = $request->tcp;
        $server->provide_to = $request->provide_to;
        $server->save();

        return redirect()->route('servers.index')->with('success', 'Server created successfully');
        
    }

    
    public function edit(Request $request, $id) {
        $categories = PromptsCategory::all();

        if ($request->ajax()) {
            $data = [
                'categories' => $categories,
            ];
    
            return response()->json($data);
        }

        $server = Server::findOrFail($id);
        // You can retrieve necessary data for the edit view if needed
        return view('admin.servers.edit', compact('server', 'categories'));
    }

    public function update(Request $request, $id) {
        $server = Server::findOrFail($id);

        $rules = [
            'country_id' => 'required',
            'country_vpn' => 'required',
            'server_name' => 'required',
            'vpn_username' => 'required',
            'vpn_password' => 'required',
            'udp' => $request->input('tcp') === null ? 'required' : 'nullable',
            'tcp' => $request->input('udp') === null ? 'required' : 'nullable',
            'provide_to' => 'required',
        ];

        $customMessage = [
            'country_id.required' => 'Please select a country.',
            'udp.required' => 'Either UDP or TCP should have a value.',
            'tcp.required' => 'Either TCP or UDP should have a value.',
        ];

        $validator = Validator::make($request->all(), $rules, $customMessage);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $server->country_id = $request->country_id;
        $server->country_vpn = $request->country_vpn;
        $server->server_name = $request->server_name;
        $server->vpn_username = $request->vpn_username;
        $server->vpn_password = $request->vpn_password;
        $server->udp = $request->udp;
        $server->tcp = $request->tcp;
        $server->provide_to = $request->provide_to;
        $server->save();

        return redirect()->route('servers.index')->with('success', 'Server updated successfully');
    }

    
    public function destroy(Request $request)
    {
        $server = Server::findOrFail($request->id);
        $server->delete();

        return redirect()->route('servers.index')->with('success', 'Server deleted successfully');
    }
}
