<?php

namespace App\Http\Controllers;

use App\Models\Chat;
use Illuminate\Http\Request;

class ChatController extends Controller
{
    public function index($session_id)
    {
        $chats = Chat::where('session_id', $session_id)->get();
        return response()->json($chats, 200);
    }

    public function store(Request $request)
    {
        $validatedData = $request->validate([
            'user_id' => 'required|exists:users,id',
            'session_id' => 'required|exists:sessions,id',
            'question' => 'required|string',
            'answer' => 'nullable|string',
        ]);

        $chat = Chat::create($validatedData);

        return response()->json($chat, 201);
    }

    public function show(Chat $chat)
    {
        $chat->load('user', 'session');
        return response()->json($chat, 200);
    }

    public function update(Request $request, Chat $chat)
    {
        $validatedData = $request->validate([
            'user_id' => 'required|exists:users,id',
            'session_id' => 'required|exists:sessions,id',
            'question' => 'required|string',
            'answer' => 'nullable|string',
        ]);

        $chat->update($validatedData);

        return response()->json($chat, 200);
    }

    public function destroy(Chat $chat)
    {
        $chat->delete();

        return response()->json(null, 204);
    }
}