<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Token;
use App\Models\Notifications;
use App\Models\Setting;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Session;
use App\Models\DeviceToken;

class NotificationController extends Controller
{

    public function notificationsList()
    {
        $notificationsList = Notifications::orderByDesc('id')->get();

        return view('admin.notification-list', ['notificationsList' => $notificationsList])->with('no', 1);
    }

    public function getAllNotifications() {
        $notifications = Notifications::all();

        return response()->json([
            'status' => 'success',
            'message' => 'Notifications retrieved successfully.',
            'data' => $notifications
        ], 200);
    }

    public function index()
    {
        session::put('page','notifi');
        return view('admin.notification');
    }

     public function send(Request $request)
    {

        $rules = [
            'title' => 'required',
            'message' => 'required',
        ];
    
        $messages = [
            'title.required' => ' Title is required',
            'message.required' => 'Message is required',
        ];
    
        $this->validate($request, $rules, $messages);
    
        $data = [
            'title' => $request->title,
            'message' => $request->message,
            'device_name' => $request->recipient,
            'url' => $request->url ?: '', // Provide a default value when the 'url' field is empty
            'image_url' => $request->image_url ?: '', // Provide a default value when the 'image_url' field is empty
        ];
        return $this->sendNotification($data);
    }



	public function sendNotification($notificationObj)
    {


        $settings = Setting::find(1);
        $SERVER_API_KEY = $settings->app_fcm_key;


        // $device_tokensArrObj = DeviceToken::all('device_token');


        // $deviceTokenArray = [];

        // foreach ($device_tokensArrObj as $tokenObj) {
        //     array_push($deviceTokenArray, $tokenObj['device_token']);
        // }


        if ($notificationObj['device_name'] === 'pro') {
            $device_tokensArrObj = DeviceToken::where('device_name', 'pro')->get('device_token');
        } elseif ($notificationObj['device_name'] === 'guest') {
            $device_tokensArrObj = DeviceToken::where('device_name', 'guest')->get('device_token');
        } else {
            $device_tokensArrObj = DeviceToken::all('device_token');
        }
    
        $deviceTokenArray = $device_tokensArrObj->pluck('device_token')->toArray();


      

        $data = [
            "registration_ids" => $deviceTokenArray,
            "notification" => [
                "body" => $notificationObj['message'],
                "title" => $notificationObj['title'],
                "image" => $notificationObj['image_url'],
                "click_action" => 'com.askrobo.app.ui.activity.SplashActivity',
                'metadata' => [
                    'key1' => 'value1',
                    'key2' => 'value2',
                    'key3' => 'value3',
                ]
            ],

            "data" =>["url" =>  $notificationObj['url']]

        ];

        
        $dataString = json_encode($data);

        $headers = [
            'Authorization: key=' . $SERVER_API_KEY,
            'Content-Type: application/json',
        ];

        $ch = curl_init();

        curl_setopt($ch, CURLOPT_URL, 'https://fcm.googleapis.com/fcm/send');
        curl_setopt($ch, CURLOPT_POST, true);
        curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
        // curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $dataString);

        $response = curl_exec($ch);

        // curl_close($ch);


        // return
        //     $response;

        if (curl_errno($ch)) {
            $error_msg = curl_error($ch);
        }
        curl_close($ch);

        if (isset($error_msg)) {
            return response()->json('error catched');
        } else {
            $notification = new Notifications();
            $notification->title = $notificationObj['title'];
            $notification->message = $notificationObj['message'];
            $notification->url = $notificationObj['url'];
            $notification->image_url = $notificationObj['image_url'];

            $notification->save();

            return redirect()->back()->with('success', 'Notification sent.');
        }
    }

    public function destroy(Request $request)
    {
        $notifications = Notifications::findOrFail($request->id);
        $notifications->delete();

        return redirect()->route('notifications.index')->with('success', 'Notification deleted successfully');
    }
}
