<?php

namespace App\Http\Controllers;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Packeg;
use App\Models\Token;
use App\Models\User;
use Illuminate\Support\Facades\Auth;

class PackegController extends Controller
{
    //
    public function index()
    {
        $packages = Packeg::orderBy('id', 'DESC')->get();
        return view('admin.packeg.index', compact('packages'))->with('no', 1);
    }

    public function indexApi()
    {
        $packegs = Packeg::orderBy('id', 'DESC')->get();
        return response()->json($packegs, 200);
    }

    public function create()
    {
        return view('admin.packeg.create');
    }

    public function store(Request $request)
    {
        $validatedData = $request->validate([
            'name' => 'required|string',
            'product_id' => 'required|string',
            'token_amout' => 'required|string',
            'pak_dua' => 'required|string',
            'pak_pric' => 'required|string',
        ]);

        Packeg::create($validatedData);

        return redirect()->route('admin.packeg.index')->with('success', 'Packeg created successfully.');
    }

    public function edit(Packeg $packeg)
    {


        return view('admin.packeg.edit', compact('packeg'));
    }


    public function activate($id)
    {
        $package = Packeg::findOrFail($id);
        $package->status = 'active';
        $package->save();

        return redirect()->back()->with('success', 'Package activated successfully');
    }

    public function deactivate($id)
    {
        $package = Packeg::findOrFail($id);
        $package->status = 'inactive';
        $package->save();

        return redirect()->back()->with('success', 'Package deactivated successfully');
    }


    public function update(Request $request, Packeg $packeg)
    {
        $validatedData = $request->validate([
            'name' => 'required|string',
            'product_id' => 'required|string',
            // 'token_amout' => 'required|string',
            'pak_dua' => 'required|string',
            'pak_pric' => 'required|string',
            // 'carecte_limit' => 'required'
        ]);

        $packeg->update($validatedData);

        return redirect()->route('admin.packeg.index')->with('success', 'Package updated successfully.');
    }

    public function destroy(Packeg $packeg)
    {
        $packeg->delete();

        return redirect()->route('admin.packeg.index')->with('success', 'Package deleted successfully.');
    }






    ///Apis
    public function buyPack(Request $request)
    {

        $validatedData = $request->validate([
            'pack_id' => 'nullable|string'
        ]);

        $user = $request->user();
        $myToken = Token::where('user_id', $user->id)->first();
        $packeg = Packeg::where('id', $request->input('pack_id'))->first();
        $token = $request->bearerToken();

        $currerntToken = $myToken->token_count;
        $newTokenCount = $currerntToken + $packeg->token_amout;


        $currerntBuyToken = $myToken->tokens_buy;
        $newBuyTokenCount = $currerntBuyToken + $packeg->token_amout;



        // return response()->json(
        //     [
        //         'token_count' => $newTokenCount,
        //         'tokens_buy' => $newBuyTokenCount,
        //     ]
        // );
        $tokenStatus = $user->login_mode ?? '';

        $myToken->update([
            'token_status' => 'pro',
            'token_count' => $newTokenCount,
            'tokens_buy' => $newBuyTokenCount,

        ]);

        $user->update([
            'login_mode' => 'pro',
            'pack_id' => $packeg->id,
            'pack_name' => $packeg->name,
            'pack_buy_date' => now(),
            'pack_exp_date' => now()->addMonth($packeg->pak_dua),
        ]);

        $userWithToken = [
            'user' => $user,
            'token' => $myToken,
        ];

        return response()->json([
            'status' => 'Package update successfully',
            'type' => 'old_user',
            'token' => $token,
            'data' => $userWithToken,
        ], 200);
    }
}
