<?php

namespace App\Http\Controllers;

use App\Models\Prompt;
use Illuminate\Http\Request;
use App\Models\PromptsCategory;



class PromptController extends Controller
{
    //
    public function index()
    {
        $prompts = Prompt::with('category')->get();
        return view('admin.prompts.index', compact('prompts'));
    }

    public function create()
    {
        $categories = PromptsCategory::all(); // Retrieve categories from the database
        return view('admin.prompts.create', compact('categories'));
    }

    public function store(Request $request)
    {
        // Validate input and store the prompt
        $validatedData = $request->validate([
            'prompts_categories_id' => 'required',
            'title' => 'required|string',
            'image_url' => 'required|image|mimes:jpeg,png,jpg,gif',
            'details' => 'required|string',
        ]);

        $image = $request->file('image_url');
        $imageName = $image->getClientOriginalName();
        $timestamp = now()->timestamp; // Get the current 
        $directory = 'prompt_images/';
        $imageUrl = $directory . $timestamp . '_' . $imageName; // Add timestamp to the filename
        $image->move($directory, $timestamp . '_' . $imageName);

        // Create prompt with image path
        Prompt::create([
            'prompts_categories_id' => $validatedData['prompts_categories_id'],
            'title' => $validatedData['title'],
            'image_url' => $imageUrl,
            'details' => $validatedData['details'],
        ]);

        return redirect()->route('prompts.index')->with('success', 'Prompt created successfully');
    }

    public function edit($id)
    {
        $prompt = Prompt::findOrFail($id);
        $categories = PromptsCategory::all(); // Retrieve categories from the database
        // You can retrieve necessary data for the edit view if needed
        return view('admin.prompts.edit', compact('prompt', 'categories'));
    }

    public function update(Request $request, $id)
    {
        $prompt = Prompt::findOrFail($id);

        // Validate input and update the prompt
        $validatedData = $request->validate([
            'prompts_categories_id' => 'required', // Use 'promts_categories_id'
            'title' => 'required|string',
            'image' => 'nullable|image|mimes:jpeg,png,jpg,gif|max:2048', // Update the image validation rules
            'details' => 'required|string',
        ]);

        // Update the prompt attributes
        $prompt->prompts_categories_id = $validatedData['prompts_categories_id'];
        $prompt->title = $validatedData['title'];
        $prompt->details = $validatedData['details'];

        // Handle image upload if provided
        if ($request->hasFile('image')) {
            unlink($prompt->image_url);

            $image = $request->file('image');
            $imageName = $image->getClientOriginalName();
            $timestamp = now()->timestamp; // Get the current 
            $directory = 'prompt_images/';
            $imageUrl = $directory . $timestamp . '_' . $imageName; // Add timestamp to the filename
            $image->move($directory, $timestamp . '_' . $imageName);

            $prompt->image_url = $imageUrl;
        }

        // Save the updated prompt
        $prompt->save();


        return redirect()->route('prompts.index')->with('success', 'Prompt updated successfully');
    }

    public function destroy($id)
    {
        $prompt = Prompt::findOrFail($id);
        $prompt->delete();

        return redirect()->route('prompts.index')->with('success', 'Prompt deleted successfully');
    }


}
