<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Token;
use App\Models\Packeg;
use Carbon\Carbon;


class TokenController extends Controller
{
    public function index()
    {
        $tokens = Token::all();

        return response()->json($tokens, 200);
    }

    public function create(Request $request)
    {
        $validatedData = $request->validate([
            'user_id' => 'required|exists:users,id',
            'token_status' => 'required',
            'token_count' => 'required',
        ]);

        $token = Token::create($validatedData);

        return response()->json($token, 201);
    }

    public function show(Token $token)
    {
        return response()->json($token, 200);
    }


    public function updateToken(Request $request)
    {
        $user = $request->user();
        $token = Token::where('user_id', $user->id)->first();
        $currentToken = $token->token_count;
        $currentCredits = $token->credits_count;

        $request->validate([
            'tokens_to_deduct' => 'required|numeric|min:1', // Ensure tokens_to_deduct is present and a positive number
        ]);

        $tokensToDeduct = $request->input('tokens_to_deduct', 1);




        if (!$user->pack_id) {
            if ($token->token_status === 'guest') {

                if ($tokensToDeduct > $currentCredits) {
                    return response()->json(['message' => 'You do not have enough available tokens.'], 400);
                }

                $token->token_status = $user->login_mode;
                $token->credits_count = max(0, $currentCredits - $tokensToDeduct);
                $token->save();
                return response()->json($token, 200);
            }
        }

        $packeg = Packeg::find($user->pack_id);

        if (!$packeg) {
            return response()->json(['message' => 'Package not found for the user.'], 404);
        }

        $remainingDays = $this->getRunningDays($user->pack_buy_date, $user->pack_exp_date);

        if (isset($user->pack_buy_date) && $remainingDays <= 0) {
            return response()->json(['message' => 'Token update failed. Pack buy date has expired.'], 20);
        } else {
            if ($token->token_status === 'pro') {

                if ($tokensToDeduct > $currentToken) {
                    return response()->json(['message' => 'You do not have enough available tokens.'], 400);
                }

                // $token->token_status = $user->login_mode;
                // $updatedTokenCount = max(0, $currentToken - 1);
                // $token->token_count = ''.$updatedTokenCount;
                // $token->save();
                // return response()->json($token, 200);

                $updatedTokenCount = max(0, $currentToken - $tokensToDeduct);
                $token->token_count = $updatedTokenCount;
                $token->save();
                return response()->json($token, 200);
            }
        }
    }


    public function updateToken1(Request $request)
{
    $user = $request->user();
    $token = Token::where('user_id', $user->id)->first();
    $packeg = Packeg::where('id', $user->pack_id)->first();
    $currentToken = $token->token_count;

    $pakDua = intval($packeg->pak_dua);

    $remainingDays = $this->getRunningDays($user->pack_buy_date,$user->pack_exp_date);

    if (isset($user->pack_buy_date) && $remainingDays <= 0) {

        return response()->json(['message' => 'Token update failed. Pack buy date has expired.'.$remainingDays.'  '], 203);

    } else{

        $token->token_status = $user->login_mode;
        $updatedTokenCount = $currentToken - 1;
        $token->token_count = ''.$updatedTokenCount;
        $token->save();
        return response()->json($token, 200);
    }


    // $response = [
    //     'token' => $token,
    //     'remainingDays' => $remainingDays,
    // ];

    // $token->save();

    //return response()->json($response, 200);
}

    public function destroy(Token $token)
    {
        $token->delete();

        return response()->json(null, 204);
    }

//     public function getRunningDays($packBuyDate){
//     $today = Carbon::today();
//     $remainingDays = abs($today->diffInDays($packBuyDate, false));

//     return $remainingDays;
// }


public function getRunningDays($packBuyDate, $packExpDate)
{

    $today = Carbon::today();
    $remainingDays = 0;

    $remai = $today->diffInDays($packExpDate, false);
    if($remai <=0){
    $remainingDays = -1;
    }else{
     $remainingDays = abs($packBuyDate->diffInDays($packExpDate, false));
    }

    return $remainingDays;
}

}
