<?php

namespace App\Http\Controllers;

use App\Models\Packeg;
use App\Models\Token;
use Illuminate\Http\Request;
use App\Models\User;
use App\Models\FreeToken;
use App\Models\Setting;
use Illuminate\Support\Facades\Session;
use App\Models\Chat;
use App\Models\DeviceToken;
//use App\Models\Session as AppSession;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Str;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\Mail;
use App\Mail\OtpEmail;
use Illuminate\Support\Facades\Cache;
use Illuminate\Validation\Rule;
use Log;


class UserController extends Controller
{
    public function store(Request $request)
    {
        $validatedData = $request->validate([
            'device_id' => 'required|string',
        ]);

        $deviceId = $request->input('device_id');
        $existingUserD = User::where('device_id', $deviceId)->first();

        if ($existingUserD) {

            $myToken = $existingUserD->token;

            $userWithToken = [
                'user' => User::findOrFail($existingUserD->id),
                'token' => $myToken,
            ];

            $token = $existingUserD->createToken('api-token')->plainTextToken;
            return response()->json([
                'status' => 'User already exists',
                'type' => 'old_user',
                'token' => $token,
                'data' => $userWithToken,

            ], 200);
        } else {

            $user = User::create($validatedData);
            // Generate a token for the user
            $token = $user->createToken('api-token')->plainTextToken;
            $userId = $user->id;
            $freeToken = Setting::first();
            $freeTokens = $freeToken->tokens;


            $myToken = Token::create([
                'user_id' => $userId,
                'token_status' => 'guest',
                'credits_count' => $freeTokens,
                'init_credits' => $freeTokens,
                'token_count' => 0,
                'tokens_buy' => 0
            ]);


            $userWithToken = [
                'user' => User::findOrFail($userId),
                'token' => $myToken,
            ];


            return response()->json([
                'status' => 'User registered successfully',
                'type' => 'new_user',
                'token' => $token,
                'data' => $userWithToken,
            ], 200);
        }
    }

    public function show(Request $request)
    {
        $user = $request->user();
        $token = $request->bearerToken();

        // Retrieve the latest (last) payment details for the user
        $latestPaymentDetails = $user->paymentDetails->first();

        $myToken = Token::where('user_id', $user->id)->first();

        $userWithTokenAndLatestPaymentDetails = [
            'user' => $user,
            'token' => $myToken,
            'payment_details' => $latestPaymentDetails,
        ];

        return response()->json([
            'status' => 'User get successfully',
            'type' => 'new_user',
            'token' => $token,
            'data' => $userWithTokenAndLatestPaymentDetails,
        ], 200);
    }

    

    public function upgradeUser(Request $request)
    {
        $validatedData = $request->validate([
            'name' => 'nullable|string',
            'first_name' => 'nullable|string',
            'last_name' => 'nullable|string',
            'email' => 'required|email',
            'password' => 'required|nullable|string', // Validate password if provided
            'phone' => 'nullable',
            'otp' => 'nullable|string',
            'pin' => 'nullable|string',
            'login_mode' => 'nullable|string',
            'device_id' => 'nullable|string',
        ]);

        $email = $request->input('email');
        $deviceId = $request->input('device_id');

        $existingUser = User::where('email', $email)->first();

        if ($existingUser) {
            // Phone number already exists, return user information
            $token = $request->bearerToken();
            $myToken = Token::where('user_id', $existingUser->id)->first();

            $userWithToken = [
                'user' => $existingUser,
                'token' => $myToken,
            ];

            return response()->json([
                'status' => 'User already exists',
                'type' => 'existing_user',
                'token' => $token,
                'data' => $userWithToken,
            ], 200);
        } else {
            // Hash the password if provided
            if ($request->has('password')) {
                $validatedData['password'] = Hash::make($validatedData['password']);
            }
            $existingUserD = User::where('device_id', $deviceId)->first();
            $token = $request->bearerToken();

            if ($existingUserD) {
                $existingUserD->update($validatedData);
                $myToken = Token::where('user_id', $existingUserD->id)->first();
                $userWithToken = [
                    'user' => $existingUserD,
                    'token' => $myToken,
                ];
                return response()->json([
                    'status' => 'User updated successfully',
                    'type' => 'new_user',
                    'token' => $token,
                    'data' => $userWithToken,
                ], 200);
            }
        }
    }


    // public function upgradeUserWithGoolge(Request $request)
    // {
    //     // Validate input data


    //     $validator = Validator::make($request->all(), [
    //         'first_name' => 'nullable|string',
    //         'last_name' => 'nullable|string',
    //         'email' => 'required|nullable|email|unique:users,email',
    //         'password' => 'required|nullable|string',
    //         'phone' => 'nullable',
    //         'otp' => 'nullable|string',
    //         'pin' => 'nullable|string',
    //         'login_mode' => 'nullable|string',
    //         'device_id' => 'nullable|string',
    //         'token' => 'required|string', // Google token
    //     ]);

    //     if ($validator->fails()) {
    //         return response()->json(['error' => $validator->errors()], 400);
    //     }

    //     $input = $request->input('token');

    //     $curl_handle = curl_init();
    //     curl_setopt($curl_handle, CURLOPT_URL, 'https://www.googleapis.com/oauth2/v1/tokeninfo?access_token=' . $input);
    //     curl_setopt($curl_handle, CURLOPT_CONNECTTIMEOUT, 0);
    //     curl_setopt($curl_handle, CURLOPT_RETURNTRANSFER, 1);
    //     $response = json_decode(curl_exec($curl_handle));
    //     curl_close($curl_handle);

    //     if (!isset($response->email)) {
    //         return response()->json(['error' => 'Wrong Google token or the token has expired.'], 401);
    //     }

    //     $email = $request->input('email');
    //     $deviceId = $request->input('device_id');

    //     $existingUser = User::where('email', $email)->first();

    //     if ($existingUser) {
    //         // Existing user found, return user information
    //         $token = $request->bearerToken();
    //         $myToken = Token::where('user_id', $existingUser->id)->first();

    //         $userWithToken = [
    //             'user' => $existingUser,
    //             'token' => $myToken,
    //         ];

    //         return response()->json([
    //             'status' => 'User already exists',
    //             'type' => 'existing_user',
    //             'token' => $token,
    //             'data' => $userWithToken,
    //         ], 200);
    //     } else {
    //         // Create or update user based on device ID
    //         if ($request->has('password')) {
    //             $request['password'] = Hash::make($request['password']);
    //         } else {
    //             $request['password'] = Hash::make(Str::random(12)); // Generate a random password
    //         }

    //         $existingUserD = User::where('device_id', $deviceId)->first();

    //         if ($existingUserD) {
    //             $existingUserD->update($request->all());

    //             // Create or update the user's token using Sanctum
    //             $token = $existingUserD->createToken('auth_token')->plainTextToken;

    //             $userWithToken = [
    //                 'user' => $existingUserD,
    //                 'token' => $token,
    //             ];

    //             return response()->json([
    //                 'status' => 'User updated successfully',
    //                 'type' => 'new_user',
    //                 'token' => $token,
    //                 'data' => $userWithToken,
    //             ], 200);
    //         }
    //     }
    // }

    public function sendOtpEmail(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'email' => 'required|email',
        ]);

        if ($validator->fails()) {
            return response()->json(['error' => $validator->errors()], 400);
        }

        $user = User::where('email', $request->email)->first();

        if (!$user) {
            return response()->json(['message' => 'User not found'], 404);
        }

        $otp = strval(random_int(100000, 999999));
        $expirationTime = now()->addMinutes(10); // Set the expiration time to 10 minutes from now
        $email = $request->input('email');

        $subject = 'Your OTP';
        $minutesRemaining = now()->diffInMinutes($expirationTime);
        $formattedTimeRemaining = $minutesRemaining === 1 ? '1 minute' : $minutesRemaining . ' minutes';
        $message = "Your OTP is: $otp. It will expire in approximately $formattedTimeRemaining.";

        Mail::raw($message, function ($message) use ($email, $subject) {
            $message->to($email)->subject($subject);
        });

        return response()->json([
            'message' => 'OTP email sent successfully',
            'otp' => $otp,
            'expiration_time' => $expirationTime->format('Y-m-d H:i:s'), // Return formatted expiration time
        ]);
    }


    public function upgradeUserWithGoogle(Request $request)
    {
        // Validate input data
        $validator = Validator::make($request->all(), [
            'otp' => 'nullable|string',
            'pin' => 'nullable|string',
            'login_mode' => 'nullable|string',
            'device_id' => 'required|string',
            'token' => 'required|string', // Google token
        ]);

        if ($validator->fails()) {
            return response()->json(['error' => $validator->errors()], 400);
        }

        $input = $request->input('token');

        //https://www.googleapis.com/auth/userinfo.profile

        $profile_curl_handle = curl_init();
        curl_setopt($profile_curl_handle, CURLOPT_URL, 'https://www.googleapis.com/oauth2/v3/userinfo');
        curl_setopt($profile_curl_handle, CURLOPT_HTTPHEADER, ['Authorization: Bearer ' . $input]);
        curl_setopt($profile_curl_handle, CURLOPT_CONNECTTIMEOUT, 0);
        curl_setopt($profile_curl_handle, CURLOPT_RETURNTRANSFER, 1);
        $response = json_decode(curl_exec($profile_curl_handle));
        curl_close($profile_curl_handle);


        //return  response()->json($response);
        if (!isset($response->email)) {
            return response()->json(['error' => 'Wrong Google token or the token has expired.'], 401);
        }

        // Extract user information from Google token response
        $email = $response->email;
        $firstName = $response->given_name ?? 'google';
        $lastName = $response->family_name ?? 'google';

        // Create or update user based on email
        $existingUser = User::where('email', $email)->first();

        if ($existingUser) {
            // Existing user found, return user information
            $token = $request->bearerToken();
            $userWithToken = [
                'user' => $existingUser,
                'token' => $token,
            ];

            return response()->json([
                'status' => 'User already exists',
                'type' => 'existing_user',
                'token' => $token,
                'data' => $userWithToken,
            ], 200);
        } else {
            // Create or update user based on device ID
            $user = new User();
            $user->name = $firstName ?? 'google'; // Use first name if available, otherwise use email
            $user->last_name = $lastName; // Set last name if available
            $user->email = $email;
            $user->password = Hash::make($email); // Generate a random password
            $user->phone = Str::random(11);
            if ($request->has('device_id')) {
                $user->device_id = $request->input('device_id');
            } else {
                $user->device_id = ''; // Set a default value or leave it empty
            }
            $user->save();

            // Create or update the user's token using Sanctum
            $token = $user->createToken('auth_token')->plainTextToken;

            $userWithToken = [
                'user' => $user,
                'token' => $token,
            ];

            return response()->json([
                'status' => 'User created successfully',
                'type' => 'new_user',
                'token' => $token,
                'data' => $userWithToken,
            ], 200);
        }
    }



    public function login(Request $request)
    {
        $credentials = $request->validate([
            'email' => 'required|email',
            'password' => 'required|string',
        ]);

        if (Auth::attempt($credentials)) {
            $user = Auth::user();

            // Update login_mode to 'pro'
            $user->login_mode = 'pro';
            $user->save();

            $existingUserD = User::where('email', $user->email)->first();
            $token = $existingUserD->createToken('api-token')->plainTextToken;

            $myToken = Token::where('user_id', $existingUserD->id)->first();

            $userWithToken = [
                'user' => $existingUserD,
                'token' => $myToken,
            ];

            return response()->json([
                'status' => 'User already exists',
                'type' => 'existing_user',
                'token' => $token,
                'data' => $userWithToken,
            ], 200);
        } else {
            return response()->json([
                'status' => 'error',
                'message' => 'Invalid credentials',
            ], 401);
        }
    }

    public function logout(Request $request)
    {
        try {
            // Check if the user is authenticated
            if (auth()->check()) {
                // Get the authenticated user
                $user = auth()->user();

                // Delete all tokens for the authenticated user
                $user->tokens()->delete();

                $user->update(['login_mode' => 'guest']);

                return response()->json([
                    'status' => 'success',
                    'message' => 'Logout successful',
                ], 200);
            } else {
                return response()->json([
                    'status' => 'error',
                    'message' => 'User not authenticated.',
                ], 401);
            }
        } catch (\Exception $e) {
            Log::error('Logout failed: ' . $e->getMessage());

            return response()->json([
                'status' => 'error',
                'message' => 'An error occurred while processing your request.',
            ], 500);
        }
    }


    public function updateUserInfoUpdate(Request $request)
    {
        $user = $request->user();
        $user->update($request->only(['name', 'pin',]));
        return response()->json([
            'status' => 'User updated successfully',
            'user' => $user,
        ], 200);
    }

    public function updatePassword(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'email' => 'required|email',
            'password' => 'required|string|min:6', // Adjust validation rules as needed
        ]);

        if ($validator->fails()) {
            return response()->json(['error' => $validator->errors()], 400);
        }
        $existingUserD = User::where('email', $request->input('email'))->first();

        if (!$existingUserD) {
            return response()->json(['message' => 'User not found'], 404);
        }

        $existingUserD->update([
            'password' => Hash::make($request->input('password')),
        ]);

        $token = $existingUserD->createToken('api-token')->plainTextToken;

        $myToken = Token::where('user_id', $existingUserD->id)->first();

        $userWithToken = [
            'user' => $existingUserD,
            'token' => $myToken,
        ];

        return response()->json([
            'status' => 'User already exists',
            'type' => 'existing_user',
            'token' => $token,
            'data' => $userWithToken,
        ], 200);
    }

    public function updateProfile(Request $request)
    {
        $validatedData = $request->validate([
            // 'name' => 'nullable|string',
            'first_name' => 'nullable|string',
            'last_name' => 'nullable|string',
            // 'email' => 'required|nullable|email|unique:users,email',
            'email' => ['required', 'email', Rule::exists(User::class, 'email')],
            'phone' => 'nullable',
        ]);



        $email = $request->input('email');

        $existingUser = User::where('email', $email)->first();

        if ($existingUser) {
            // $existingUser->name = $request->name;
            $existingUser->first_name = $request->first_name;
            $existingUser->last_name = $request->last_name;
            $existingUser->email = $request->email;
            $existingUser->phone = $request->phone;
            $existingUser->save();

            return response()->json([
                'status' => 'success',
                'message' => 'Profile updated successfully.',
            ], 200);

        } else {
            return response()->json([
                'status' => 'error',
                'message' => 'Can"t update profile.',
            ], 500);
        }
    }

    ///Admin part
    public function index($login_mode = null)
    {
        Session::put('page', 'iser');
        $users = User::orderBy('id', 'DESC');

        if (!is_null($login_mode)) {
            $users->where('login_mode', $login_mode);
        }

        $users = $users->get();
        
        return view('admin.users.index', compact('users'))->with('no', 1);
    }


    public function edit($id)
    {
        $userData = User::find($id);
        $packages = Packeg::get();

        return view('admin.users.edit', compact('userData', 'packages'));
    }


    public function userUpdate(Request $request)
    {

        $validatedData = $request->validate([
            'name' => 'nullable|string',
            'package_id' => 'nullable|string',
        ]);

        //@dd($request->all());

        $userData11 = json_decode($request->input('user'));
        // Set other properties as needed

        $user = User::findOrFail($userData11->id);
        $myToken = Token::where('user_id', $user->id)->first();
        $packeg = Packeg::where('id', $request->input('package_id'))->first();




        if ($request->input('package_id') != $user->pack_id) {
            $currerntToken = $myToken->token_count;
            $newTokenCount = $currerntToken + $packeg->token_amout;
            $tokenStatus = $user->login_mode ?? '';
            $myToken->update([
                'token_status' => $tokenStatus,
                'token_count' => $newTokenCount,
            ]);
            $user->update([
                'name' => $request->input('name'),
                'login_mode' => $tokenStatus,
                'pack_id' => $packeg->id,
                'pack_name' => $packeg->name,
                'pack_buy_date' => now(),
                'pack_exp_date' => now()->addDays($packeg->pak_dua),

            ]);
        } else {
            $user->update([
                'name' => $request->input('name'),
            ]);
        }





        $userData = $user;
        $packages = Packeg::all();

        //return view('admin.users.edit',compact('userData','packages'));
        $users = User::orderBy('id', 'DESC')->get();
        return view('admin.users.index', compact('users'))->with('no', 1);
    }






    public function userUpdateAdmin(Request $request)
    {

        $validatedData = $request->validate([
            'name' => 'nullable|string',
            'package_id' => 'nullable|string',
        ]);

        //@dd($request->all());

        $userData11 = json_decode($request->input('user'));
        // Set other properties as needed

        $user = User::findOrFail($userData11->id);
        $myToken = Token::where('user_id', $user->id)->first();
        $packeg = Packeg::where('id', $request->input('package_id'))->first();




        if ($request->input('package_id') != $user->pack_id) {
            $currerntToken = $myToken->token_count;
            $newTokenCount = $currerntToken + $packeg->token_amout;

            $currerntBuyToken = $myToken->tokens_buy;
            $newBuyTokenCount = $currerntBuyToken + $packeg->token_amout;

            $userStatus = $user->login_mode ?? ''; // Use the user's type if available, otherwise set to empty string

            $myToken->update([
                //'token_status' => $tokenStatus,
                'token_status' => 'pro',
                'token_count' => $newTokenCount,
                'tokens_buy' => $newBuyTokenCount,
            ]);

            $user->update([
                'name' => $request->input('name'),
                'login_mode' => $userStatus, // This line is causing the error
                'pack_id' => $packeg->id,
                'pack_name' => $packeg->name,
                'pack_buy_date' => now(),
                'pack_exp_date' => now()->addDays($packeg->pak_dua),
            ]);
        } else {
            $user->update([
                'name' => $request->input('name'),
            ]);
        }





        $userData = $user;
        $packages = Packeg::all();

        //return view('admin.users.edit',compact('userData','packages'));
        $users = User::orderBy('id', 'DESC')->get();
        return view('admin.users.index', compact('users'))->with('no', 1);
    }







    public function destroy($id)
    {
        // Find the user by ID
        $user = User::find($id);

        // Check if the user exists
        if (!$user) {
            return redirect()->back()->with('error', 'User not found.');
        }

        // Delete the user's token (assuming you have a one-to-one relationship)
        if ($user->token) {
            $user->token->delete();
        }

        // Delete the user's device tokens (assuming you have a one-to-many relationship)
        if ($user->deviceTokens) {
            $user->deviceTokens()->delete();
        }

        // Delete the user's chats (assuming you have a one-to-many relationship)
        if ($user->chats) {
            $user->chats()->delete();
        }

        // Delete all sessions and chats associated with the user
        $user->sessions->each(function ($session) {
            $session->chats->each(function ($chat) {
                $chat->delete();
            });
            $session->delete();
        });

        // Now, delete the user itself
        $user->delete();

        // Redirect back to the user index page or any other appropriate page
        Session::put('page', 'user_index');
        return redirect()->route('admin.users.index')->with('success', 'User and associated sessions/chats deleted successfully.');
    }
}
