<?php

use Illuminate\Support\Facades\Route;
use App\Http\Controllers\AdminController;
use App\Http\Controllers\FreeTokenController;
use App\Http\Controllers\UserController;
use App\Http\Controllers\PackegController;
use App\Http\Controllers\SettingsController;
use App\Http\Controllers\NotificationController;
use App\Http\Controllers\PromptsCategoryController;
use App\Http\Controllers\PromptController;
use App\Http\Controllers\TokensPrichingController;
use App\Http\Controllers\AdvertisementController;
use App\Http\Controllers\AllserverController;
use App\Http\Controllers\OTPMailController;
use Illuminate\Support\Facades\Artisan;


/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

Route::get('/', function () {
    return view('welcome');
});

Route::get('/linkstorage', function () {
    Artisan::call('storage:link');
});

Route::get('/debug-image-url', function () {
    error_log(request()->fullUrl());
});


Route::prefix('/admin')->namespace('Admin')->group(function () {
    //All the admin route will be define here:-

    Route::match(['get', 'post'], '/', [AdminController::class, 'login']);

    Route::group(['middleware' => ['admin']], function () {

        Route::get('dashboard', [AdminController::class, 'dashboard']);
        Route::get('logout', [AdminController::class, 'logout']);


        //Package Route
        Route::get('packeg_index', [PackegController::class, 'index']);
        Route::get('package_active/{id}', [PackegController::class, 'activate']);
        Route::get('package_inactive/{id}', [PackegController::class, 'deactivate']);
        Route::get('/admin/packeg', [PackegController::class, 'index'])->name('admin.packeg.index');
        Route::get('package_edit/{packeg}', [PackegController::class, 'edit']);
        Route::post('packeg/{packeg}', [PackegController::class, 'update']);
        // Route::delete('packeg/{packeg}', [PackegController::class, 'destroy']);

  

        //User Route
        Route::get('user_index/{login_mode?}', [UserController::class, 'index']);
        Route::get('user_edit/{id}', [UserController::class, 'edit']);
        Route::post('admin/user_update/{user}', [UserController::class, 'userUpdateAdmin'])->name('admin.user_update');
        Route::get('users', [UserController::class, 'index'])->name('admin.users.index');
        Route::delete('users/{userId}', [UserController::class, 'destroy'])->name('admin.users.destroy');



        //Administrator Route
        Route::get('Aindex', [AdminController::class, 'index']);
        Route::get('Acreate', [AdminController::class, 'create']);
        Route::post('Asubmit', [AdminController::class, 'store']);
        Route::get('Aedit/{id}', [AdminController::class, 'edit']);
        Route::post('Aupdate/{id}', [AdminController::class, 'update']);
        Route::get('Adelete/{id}', [AdminController::class, 'destroy']);


        //Notification Route
        Route::get('notifications/list', [NotificationController::class, 'notificationsList'])->name('notifications.index');;
        Route::delete('notifications/{id}', [NotificationController::class, 'destroy'])->name('notifications.destroy');

        Route::get('notifications', [NotificationController::class, 'index']);
        Route::post('notifications/send', [NotificationController::class, 'send']);


        //Settings Route
        Route::get('settings', [SettingsController::class, 'index']);
        Route::post('settings/update', [SettingsController::class, 'update']);

        //Settings Route
        Route::get('free/tokens', [FreeTokenController::class, 'index']);
        Route::get('freetoken_edit/{freeToken}', [FreeTokenController::class, 'edit']);
        Route::post('free/tokens/update/{id}', [FreeTokenController::class, 'update']);
        Route::get('/admin/freetokens', [FreeTokenController::class, 'index'])->name('admin.freetokens.index');


        // Routes for the Settings section
        Route::get('settings', [SettingsController::class, 'index'])->name('settings');
        Route::get('settings/otp-mail', [OTPMailController::class, 'showOTPMailForm']);
        Route::post('settings/update/otp-mail', [OTPMailController::class, 'updateOTPMail']);
        Route::get('settings/general', [SettingsController::class, 'generalSettings'])->name('general_settings');
        Route::post('otp-settings/update', [SettingsController::class, 'updateOTPConfiguration']);
        Route::post('general-settings/update', [SettingsController::class, 'updateGeneralSettings']);

        Route::get('country', [PromptsCategoryController::class, 'index'])->name('prompts-categories.index');
        Route::get('country/create', [PromptsCategoryController::class, 'create'])->name('country.create');
        Route::post('prompts-categories', [PromptsCategoryController::class, 'store'])->name('prompts-categories.store');
        Route::get('country/edit/{id}', [PromptsCategoryController::class, 'edit'])->name('country.edit');
        Route::post('country/update/{id}', [PromptsCategoryController::class, 'update'])->name('country.update');
        Route::delete('/country/destroy/{id}', [PromptsCategoryController::class, 'destroy'])->name('country.destroy');

        // Server Route
        Route::get('servers', [AllserverController::class, 'index'])->name('servers.index');
        Route::get('servers/create', [AllserverController::class, 'create'])->name('servers.create');
        Route::post('servers', [AllserverController::class, 'store'])->name('servers.store');
        Route::get('servers/edit/{id?}', [AllserverController::class, 'edit'])->name('servers.edit');
        Route::post('servers/{id}', [AllserverController::class, 'update'])->name('servers.update');
        Route::delete('servers/{id}', [AllserverController::class, 'destroy'])->name('servers.destroy');


        //Tokens Priching
        Route::get('tokens/priching', [TokensPrichingController::class, 'index'])->name('tokens.priching.index');
        Route::get('tokens/priching/create', [TokensPrichingController::class, 'create'])->name('tokens-prichings.create');
        Route::post('tokens/priching/store', [TokensPrichingController::class, 'store'])->name('tokens-prichings.store');
        Route::get('tokens_priching_edit/{tokens}', [TokensPrichingController::class, 'edit'])->name('tokens-prichings.edit');
        Route::PUT('tokens_priching_edit/{tokens}', [TokensPrichingController::class, 'update'])->name('tokens-prichings.update');
        Route::delete('tokens_priching_edit/{tokens}', [TokensPrichingController::class, 'destroy'])->name('tokens-prichings.destroy');

        Route::get('advertisement', [AdvertisementController::class, 'index']);
        Route::post('advertisement/update', [AdvertisementController::class, 'update']);




        // Route::get('tokens_priching_active/{id}', [PackegController::class, 'activate']);
        // Route::get('tokens_priching_inactive/{id}', [PackegController::class, 'deactivate']);
        // Route::post('tokens_priching/{tokens}', [PackegController::class, 'update'])->name('tokens.priching.index');
    });
});
